@@ -9,37 +9,34 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Exception;
 use Template ();
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 sub register {
     my ( $self, $app, $settings ) = @_;
 
-    $settings->{'config'}{'RELATIVE'}     //= 1;
-    $settings->{'config'}{'EVAL_PERL'}    //= 0;
-    $settings->{'config'}{'INCLUDE_PATH'} //= $app->renderer->paths;
+    $settings->{config}{RELATIVE}     //= 1;
+    $settings->{config}{EVAL_PERL}    //= 0;
+    $settings->{config}{INCLUDE_PATH} //= $app->renderer->paths;
 
-    my $template = Template->new( $settings->{'config'} );
+    my $template = Template->new( $settings->{config} );
 
-    $settings->{'context'}->( $template->context ) if ( $settings->{'context'} );
+    $settings->{context}->( $template->context ) if ( $settings->{context} );
 
-    $app->renderer->add_handler( 'tt' => sub {
+    $app->renderer->add_handler( tt => sub {
         my ( $renderer, $controller, $output, $options ) = @_;
-        my $inline = $settings->{'settings'}{'inline_template'} || 'inline';
+        my $inline = $settings->{settings}{inline_template} || 'inline';
 
         $template->process(
             ( ( $options->{$inline} ) ? \$options->{$inline} : $renderer->template_name($options) ),
             {
-                'content' => $controller->content,
+                content => $controller->content,
                 %{ $controller->stash },
-                ( $settings->{'settings'}{'controller'} || 'c' ) => $controller,
+                ( $settings->{settings}{controller} || 'c' ) => $controller,
             },
             $output,
         ) || do {
-            if (
-                $app->mode ne 'development' and
-                ref( $settings->{'settings'}{'error_handler'} ) eq 'CODE'
-            ) {
-                $settings->{'settings'}{'error_handler'}->( $controller, $renderer, $app );
+            if ( ref( $settings->{settings}{error_handler} ) eq 'CODE' ) {
+                $settings->{settings}{error_handler}->( $controller, $renderer, $app, $template );
             }
             else {
                 unless (
@@ -48,18 +45,13 @@ sub register {
                         $template->error eq 'file error - exception.' . $app->mode . '.html.tt: not found'
                     )
                 ) {
-                    my $default_handler = $renderer->default_handler;
-                    $renderer->default_handler('ep');
-
-                    $controller->reply->exception(
-                        Mojo::Exception->new( __PACKAGE__ . ' - ' . $template->error )
-                    );
+                    $$output = $template->error;
+                    $controller->res->headers->content_type('text/plain');
 
+                    $controller->log->error( $template->error );
                     $controller->rendered(
                         ( $template->error and $template->error =~ /not found/ ) ? 404 : 500
                     );
-
-                    $renderer->default_handler($default_handler);
                 }
             }
         };
@@ -68,8 +60,8 @@ sub register {
     } );
 
     $app->helper(
-        'render_tt' => sub {
-            shift->render( 'handler' => 'tt', @_ );
+        render_tt => sub {
+            shift->render( handler => 'tt', @_ );
         }
     );
 
@@ -90,7 +82,7 @@ Mojolicious::Plugin::ToolkitRenderer - Template Toolkit Renderer Mojolicious Plu
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit.svg)](https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Mojo-Plugin-Toolkit/badge.png)](https://coveralls.io/r/gryphonshafer/Mojo-Plugin-Toolkit)
@@ -186,12 +178,10 @@ The "controller" settings lets your defined what keyword you can use within your
 TT templates that will be a reference to the Mojolicious controller.
 
 The "error_handler" setting lets you provide an optional subroutine reference
-that will get called if there is any TT errors. By default, when in development
-mode, TT errors will surface in the normal Mojolicious helpful way (browser
-page and logs). But you can override this.
+that will get called if there is any TT errors.
 
     error_handler => sub {
-        my ( $controller, $renderer, $app ) = @_;
+        my ( $controller, $renderer, $app, $template ) = @_;
 
         unless (
             $template->error and (
@@ -199,18 +189,13 @@ page and logs). But you can override this.
                 $template->error eq 'file error - exception.' . $app->mode . '.html.tt: not found'
             )
         ) {
-            my $default_handler = $renderer->default_handler;
-            $renderer->default_handler('ep');
-
-            $controller->reply->exception(
-                Mojo::Exception->new( __PACKAGE__ . ' - ' . $template->error )
-            );
+            $$output = $template->error;
+            $controller->res->headers->content_type('text/plain');
 
+            $controller->log->error( $template->error );
             $controller->rendered(
                 ( $template->error and $template->error =~ /not found/ ) ? 404 : 500
             );
-
-            $renderer->default_handler($default_handler);
         }
     }
 
@@ -238,18 +223,10 @@ L<GitHub|https://github.com/gryphonshafer/Mojo-Plugin-Toolkit>
 
 =item *
 
-L<CPAN|http://search.cpan.org/dist/Mojolicious-Plugin-ToolkitRenderer>
-
-=item *
-
 L<MetaCPAN|https://metacpan.org/pod/Mojolicious::Plugin::ToolkitRenderer>
 
 =item *
 
-L<AnnoCPAN|http://annocpan.org/dist/Mojolicious-Plugin-ToolkitRenderer>
-
-=item *
-
 L<Travis CI|https://travis-ci.org/gryphonshafer/Mojo-Plugin-Toolkit>
 
 =item *
@@ -272,7 +249,7 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gryphon Shafer.
+This software is copyright (c) 2020 by Gryphon Shafer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
